%define debug_package %{nil}
%define erlang_minver 26.0
%define erlang_maxver 27.0
%define upstream_version 3.13.0

Name: rabbitmq-server
Version: 3.13.0
Release: 1%{?dist}
License: MPLv2.0 and MIT and ASL 2.0 and BSD
Group: %{group_tag}
Source: https://github.com/rabbitmq/rabbitmq-server/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1: rabbitmq-server.init
Source2: rabbitmq-server.logrotate
Source3: rabbitmq-server.service
Source4: rabbitmq-server.tmpfiles
URL: https://www.rabbitmq.com/
BuildArch: noarch
BuildRequires: erlang >= %{erlang_minver}
BuildRequires: elixir
BuildRequires: gzip, sed, zip, rsync
BuildRequires:  systemd

Requires: erlang >= %{erlang_minver}, erlang < %{erlang_maxver},
Requires: logrotate
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-%{_arch}-root
Summary: The RabbitMQ server

%if 0%{?fedora} || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1315
Requires(pre): systemd
Requires(post): systemd
Requires(preun): systemd
%else
Requires(post): chkconfig initscripts
Requires(pre): chkconfig initscripts
%endif

%description
RabbitMQ is an open source multi-protocol messaging and streaming broker.

# We want to install into /usr/lib, even on 64-bit platforms
%define _rabbit_libdir %{_exec_prefix}/lib/rabbitmq
%define _rabbit_erllibdir %{_rabbit_libdir}/lib/rabbitmq_server-%{upstream_version}
%define _plugins_state_dir %{_localstatedir}/lib/rabbitmq/plugins
%define _rabbitmqctl_autocomplete scripts/rabbitmqctl-autocomplete.sh
%define _rabbitmq_user rabbitmq
%define _rabbitmq_group rabbitmq


%define _maindir %{buildroot}%{_rabbit_erllibdir}


%prep
%setup -q -n %{name}-%{upstream_version}

%build
cp -a deps/rabbit/docs/README-for-packages %{_builddir}/rabbitmq-server-%{upstream_version}/README
env -u DEPS_DIR make dist manpages

%install
rm -rf %{buildroot}

env -u DEPS_DIR make install install-bin install-man DESTDIR=%{buildroot} PREFIX=%{_exec_prefix} RMQ_ROOTDIR=%{_rabbit_libdir} RMQ_ERLAPP_DIR=%{_rabbit_erllibdir} MANDIR=%{_mandir}

mkdir -p %{buildroot}%{_localstatedir}/lib/rabbitmq/mnesia
mkdir -p %{buildroot}%{_localstatedir}/log/rabbitmq

#Copy all necessary lib files etc.

%if 0%{?fedora} || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1315
install -p -D -m 0644 %{S:3} %{buildroot}%{_unitdir}/%{name}.service
%else
install -p -D -m 0755 %{S:1} %{buildroot}%{_initrddir}/rabbitmq-server
%endif

install -p -D -m 0644 %{S:2} %{buildroot}%{_sysconfdir}/logrotate.d/rabbitmq-server

install -p -D -m 0755 %{_rabbitmqctl_autocomplete} %{buildroot}%{_sysconfdir}/profile.d/rabbitmqctl-autocomplete.sh
install -p -D -m 0755 scripts/zsh_autocomplete.sh %{buildroot}%{_datarootdir}/zsh/vendor-functions/_enable_rabbitmqctl_completion


mkdir -p %{buildroot}%{_sysconfdir}/rabbitmq

mkdir -p %{buildroot}%{_sbindir}
sed \
	-e 's|@RABBITMQ_USER@|%{_rabbitmq_user}|' -e 's|@RABBITMQ_GROUP@|%{_rabbitmq_group}|' \
	< scripts/rabbitmq-script-wrapper \
	> %{buildroot}%{_sbindir}/rabbitmqctl
chmod 0755 %{buildroot}%{_sbindir}/rabbitmqctl
for script in rabbitmq-server rabbitmq-plugins rabbitmq-diagnostics rabbitmq-queues rabbitmq-upgrade rabbitmq-streams; do \
	cp -a %{buildroot}%{_sbindir}/rabbitmqctl \
	 %{buildroot}%{_sbindir}/$script; \
done

%if 0%{?fedora} > 30 || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1315
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%endif

rm %{_maindir}/LICENSE* %{_maindir}/INSTALL

#Build the list of files
echo '%defattr(-,root,root, -)' >%{_builddir}/%{name}.files
find %{buildroot} -path %{buildroot}%{_sysconfdir} -prune -o '!' -type d -printf "/%%P\n" >>%{_builddir}/%{name}.files
find %{buildroot} -path "*%{_initrddir}*" -type f -printf "/%%P\n" >>%{_builddir}/%{name}.files

%pre

# If the log directory exists, record its permissions so we can restore
# them after an upgrade. The goal is to set the permissions to 0750 on a
# fresh install but to keep permissions set by the user or a different
# default from a previous package.
if test -d /var/log/rabbitmq; then
    stat --format '%a' /var/log/rabbitmq > /var/log/rabbitmq/permissions
fi

if [ "$1" = 2 ]; then
  # Upgrade:
  # Stop previous instance of rabbitmq-server. But before doing this, we
  # also record if the service is running: it is used again in %post to
  # restart the service.
  if %{_sbindir}/rabbitmqctl status >/dev/null 2>&1; then
    touch %{_localstatedir}/lib/rabbitmq/rabbitmq-running-before-upgrade
  else
    rm -f %{_localstatedir}/lib/rabbitmq/rabbitmq-running-before-upgrade
  fi

%if 0%{?fedora} || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1315
  systemctl stop rabbitmq-server
%else
  /sbin/service rabbitmq-server stop
%endif
fi

# create rabbitmq group
if ! getent group rabbitmq >/dev/null; then
        groupadd -r rabbitmq
fi

# create rabbitmq user
if ! getent passwd rabbitmq >/dev/null; then
        useradd -r -g rabbitmq -d %{_localstatedir}/lib/rabbitmq -s /sbin/nologin rabbitmq \
            -c "RabbitMQ messaging server"
fi

%post

%if 0%{?fedora} || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1315
# %%systemd_post %%{name}.service
# manual expansion of systemd_post as this doesn't appear to
# expand correctly on debian machines
if [ $1 -eq 1 ] ; then
    # Initial installation
    systemctl preset %{name}.service >/dev/null 2>&1 || :
fi
systemctl daemon-reload
%else
/sbin/chkconfig --add %{name}
%endif

chmod -R o-rwx,g-w %{_localstatedir}/lib/rabbitmq/mnesia
chgrp rabbitmq %{_sysconfdir}/rabbitmq

# Restore permissions saved during %pre. See comment in %pre for the
# reason behind this.
if test -f /var/log/rabbitmq/permissions; then
    chmod "$(cat /var/log/rabbitmq/permissions)" /var/log/rabbitmq
    rm -f /var/log/rabbitmq/permissions
fi

if [ "$1" = 2 ] ; then
  # Upgrade:
  # Restart the service if it was running before the upgrade.
  if [ -f %{_localstatedir}/lib/rabbitmq/rabbitmq-running-before-upgrade ]; then
%if 0%{?fedora} || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1315
    # %%systemd_postun_with_restart %%{name}.service
    # manual expansion of systemd_postun_with_restart as this doesn't appear to
    # expand correctly on debian machines
    systemctl restart %{name}.service >/dev/null 2>&1 || :
%else
    /sbin/service %{name} restart
%endif
    rm -f %{_localstatedir}/lib/rabbitmq/rabbitmq-running-before-upgrade
  fi
fi

if [ -n "$ZSH_VERSION" ]; then
    echo "Z Shell detected.
to enable rabbitmqctl autocompletion add the following to your .zshrc file:
autoload _enable_rabbitmqctl_completion; _enable_rabbitmqctl_completion"
fi

%preun

if [ $1 = 0 ]; then
  #Complete uninstall
%if 0%{?fedora} || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1315
  systemctl stop rabbitmq-server
%else
  /sbin/service rabbitmq-server stop
  /sbin/chkconfig --del rabbitmq-server
%endif

  # We do not remove /var/log and /var/lib directories
  # Leave rabbitmq user and group
fi

# Clean out plugin activation state, both on uninstall and upgrade
rm -rf %{_plugins_state_dir}
for ext in rel script boot ; do
    rm -f %{_rabbit_erllibdir}/ebin/rabbit.$ext
done

%postun

%files -f ../%{name}.files
%defattr(-,root,root,-)
%attr(0755, rabbitmq, rabbitmq) %dir %{_localstatedir}/lib/rabbitmq
%attr(0750, rabbitmq, rabbitmq) %dir %{_localstatedir}/lib/rabbitmq/mnesia
%attr(0755, rabbitmq, rabbitmq) %dir %{_localstatedir}/log/rabbitmq
%attr(2755, -, rabbitmq) %dir %{_sysconfdir}/rabbitmq

%{_sysconfdir}/profile.d/rabbitmqctl-autocomplete.sh
%{_datarootdir}/zsh/vendor-functions/_enable_rabbitmqctl_completion

%config(noreplace) %{_sysconfdir}/logrotate.d/rabbitmq-server
%doc LICENSE*
%doc README
%doc deps/rabbit/docs/set_rabbitmq_policy.sh.example

%clean
rm -rf %{buildroot}

%changelog
* Mon Mar 17 2025 Kaiqiang Wang <wangkaiqiang@ieisystem.com> 3.13.0-1
- update to 3.13.0.
